import requests
import logging

_LOGGER = logging.getLogger(__name__)

API_URL = "https://redgtech-dev.com"

class RedgtechAPI:
    def __init__(self, token):
        self._token = token
        self._session = requests.Session()

    def close(self):
        self._session.close()

    def get_data(self):
        url = f"{API_URL}/home_assistant?access_token={self._token}"
        response = self._session.get(url)
        response.raise_for_status()
        return response.json()

    def set_switch_state(self, endpoint_id, state):
        id_part, after_id = endpoint_id.split("-", 1)
        number_channel = after_id[-1]
        type_channel = ''.join(char for char in after_id if char.isalpha())
        state_char = 'l' if state else 'd'
        value = f"{number_channel}{state_char}" if type_channel == "AC" else f"{type_channel}{number_channel}*{state_char}*"
        url = f"{API_URL}/home_assistant/execute/{id_part}?cod=?{value}"
        headers = {"Authorization": f"{self._token}"}
        response = self._session.get(url, headers=headers)
        return response.status_code == 200

    def set_light_brightness(self, endpoint_id, brightness):
        id_part, after_id = endpoint_id.split("-", 1)
        number_channel = after_id[-1]
        type_channel = ''.join(char for char in after_id if char.isalpha())
        brightness_value = round((brightness / 255) * 100)
        value = f"{type_channel}{number_channel}*{brightness_value}*"
        url = f"{API_URL}/home_assistant/execute/{id_part}?cod=?{value}"
        headers = {"Authorization": f"{self._token}"}
        response = self._session.get(url, headers=headers)
        return response.status_code == 200